<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'Automattic\\Jetpack\\Autoloader\\AutoloadFileWriter' => $vendorDir . '/automattic/jetpack-autoloader/src/AutoloadFileWriter.php',
    'Automattic\\Jetpack\\Autoloader\\AutoloadGenerator' => $vendorDir . '/automattic/jetpack-autoloader/src/AutoloadGenerator.php',
    'Automattic\\Jetpack\\Autoloader\\AutoloadProcessor' => $vendorDir . '/automattic/jetpack-autoloader/src/AutoloadProcessor.php',
    'Automattic\\Jetpack\\Autoloader\\CustomAutoloaderPlugin' => $vendorDir . '/automattic/jetpack-autoloader/src/CustomAutoloaderPlugin.php',
    'Automattic\\Jetpack\\Autoloader\\ManifestGenerator' => $vendorDir . '/automattic/jetpack-autoloader/src/ManifestGenerator.php',
    'Automattic\\Jetpack\\Constants' => $vendorDir . '/automattic/jetpack-constants/src/class-constants.php',
    'Automattic\\WooCommerce\\Admin\\API\\Coupons' => $baseDir . '/packages/woocommerce-admin/src/API/Coupons.php',
    'Automattic\\WooCommerce\\Admin\\API\\CustomAttributeTraits' => $baseDir . '/packages/woocommerce-admin/src/API/CustomAttributeTraits.php',
    'Automattic\\WooCommerce\\Admin\\API\\Customers' => $baseDir . '/packages/woocommerce-admin/src/API/Customers.php',
    'Automattic\\WooCommerce\\Admin\\API\\Data' => $baseDir . '/packages/woocommerce-admin/src/API/Data.php',
    'Automattic\\WooCommerce\\Admin\\API\\DataCountries' => $baseDir . '/packages/woocommerce-admin/src/API/DataCountries.php',
    'Automattic\\WooCommerce\\Admin\\API\\DataDownloadIPs' => $baseDir . '/packages/woocommerce-admin/src/API/DataDownloadIPs.php',
    'Automattic\\WooCommerce\\Admin\\API\\Features' => $baseDir . '/packages/woocommerce-admin/src/API/Features.php',
    'Automattic\\WooCommerce\\Admin\\API\\Init' => $baseDir . '/packages/woocommerce-admin/src/API/Init.php',
    'Automattic\\WooCommerce\\Admin\\API\\Leaderboards' => $baseDir . '/packages/woocommerce-admin/src/API/Leaderboards.php',
    'Automattic\\WooCommerce\\Admin\\API\\Marketing' => $baseDir . '/packages/woocommerce-admin/src/API/Marketing.php',
    'Automattic\\WooCommerce\\Admin\\API\\MarketingOverview' => $baseDir . '/packages/woocommerce-admin/src/API/MarketingOverview.php',
    'Automattic\\WooCommerce\\Admin\\API\\NavigationFavorites' => $baseDir . '/packages/woocommerce-admin/src/API/NavigationFavorites.php',
    'Automattic\\WooCommerce\\Admin\\API\\NoteActions' => $baseDir . '/packages/woocommerce-admin/src/API/NoteActions.php',
    'Automattic\\WooCommerce\\Admin\\API\\Notes' => $baseDir . '/packages/woocommerce-admin/src/API/Notes.php',
    'Automattic\\WooCommerce\\Admin\\API\\OnboardingFreeExtensions' => $baseDir . '/packages/woocommerce-admin/src/API/OnboardingFreeExtensions.php',
    'Automattic\\WooCommerce\\Admin\\API\\OnboardingPayments' => $baseDir . '/packages/woocommerce-admin/src/API/OnboardingPayments.php',
    'Automattic\\WooCommerce\\Admin\\API\\OnboardingProductTypes' => $baseDir . '/packages/woocommerce-admin/src/API/OnboardingProductTypes.php',
    'Automattic\\WooCommerce\\Admin\\API\\OnboardingProfile' => $baseDir . '/packages/woocommerce-admin/src/API/OnboardingProfile.php',
    'Automattic\\WooCommerce\\Admin\\API\\OnboardingTasks' => $baseDir . '/packages/woocommerce-admin/src/API/OnboardingTasks.php',
    'Automattic\\WooCommerce\\Admin\\API\\OnboardingThemes' => $baseDir . '/packages/woocommerce-admin/src/API/OnboardingThemes.php',
    'Automattic\\WooCommerce\\Admin\\API\\Options' => $baseDir . '/packages/woocommerce-admin/src/API/Options.php',
    'Automattic\\WooCommerce\\Admin\\API\\Orders' => $baseDir . '/packages/woocommerce-admin/src/API/Orders.php',
    'Automattic\\WooCommerce\\Admin\\API\\Plugins' => $baseDir . '/packages/woocommerce-admin/src/API/Plugins.php',
    'Automattic\\WooCommerce\\Admin\\API\\ProductAttributeTerms' => $baseDir . '/packages/woocommerce-admin/src/API/ProductAttributeTerms.php',
    'Automattic\\WooCommerce\\Admin\\API\\ProductAttributes' => $baseDir . '/packages/woocommerce-admin/src/API/ProductAttributes.php',
    'Automattic\\WooCommerce\\Admin\\API\\ProductCategories' => $baseDir . '/packages/woocommerce-admin/src/API/ProductCategories.php',
    'Automattic\\WooCommerce\\Admin\\API\\ProductReviews' => $baseDir . '/packages/woocommerce-admin/src/API/ProductReviews.php',
    'Automattic\\WooCommerce\\Admin\\API\\ProductVariations' => $baseDir . '/packages/woocommerce-admin/src/API/ProductVariations.php',
    'Automattic\\WooCommerce\\Admin\\API\\Products' => $baseDir . '/packages/woocommerce-admin/src/API/Products.php',
    'Automattic\\WooCommerce\\Admin\\API\\ProductsLowInStock' => $baseDir . '/packages/woocommerce-admin/src/API/ProductsLowInStock.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Cache' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Cache.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Categories\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Categories/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Categories\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Categories/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Categories\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Categories/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Coupons\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Coupons/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Coupons\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Coupons/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Coupons\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Coupons/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Coupons\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Coupons/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Coupons\\Stats\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Coupons/Stats/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Coupons\\Stats\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Coupons/Stats/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Coupons\\Stats\\Segmenter' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Coupons/Stats/Segmenter.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Customers\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Customers/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Customers\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Customers/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Customers\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Customers/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Customers\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Customers/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Customers\\Stats\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Customers/Stats/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Customers\\Stats\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Customers/Stats/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\DataStoreInterface' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/DataStoreInterface.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Downloads\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Downloads/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Downloads\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Downloads/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Downloads\\Files\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Downloads/Files/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Downloads\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Downloads/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Downloads\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Downloads/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Downloads\\Stats\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Downloads/Stats/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Downloads\\Stats\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Downloads/Stats/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Export\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Export/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\ExportableInterface' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/ExportableInterface.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\ExportableTraits' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/ExportableTraits.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Import\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Import/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Orders\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Orders/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Orders\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Orders/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Orders\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Orders/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Orders\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Orders/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Orders\\Stats\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Orders/Stats/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Orders\\Stats\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Orders/Stats/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Orders\\Stats\\Segmenter' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Orders/Stats/Segmenter.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\ParameterException' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/ParameterException.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\PerformanceIndicators\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/PerformanceIndicators/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Products\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Products/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Products\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Products/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Products\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Products/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Products\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Products/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Products\\Stats\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Products/Stats/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Products\\Stats\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Products/Stats/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Products\\Stats\\Segmenter' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Products/Stats/Segmenter.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Revenue\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Revenue/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Revenue\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Revenue/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Segmenter' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Segmenter.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\SqlQuery' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/SqlQuery.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Stock\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Stock/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Stock\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Stock/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Stock\\Stats\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Stock/Stats/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Stock\\Stats\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Stock/Stats/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Taxes\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Taxes/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Taxes\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Taxes/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Taxes\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Taxes/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Taxes\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Taxes/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Taxes\\Stats\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Taxes/Stats/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Taxes\\Stats\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Taxes/Stats/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Taxes\\Stats\\Segmenter' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Taxes/Stats/Segmenter.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\TimeInterval' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/TimeInterval.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Variations\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Variations/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Variations\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Variations/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Variations\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Variations/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Variations\\Stats\\Controller' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Variations/Stats/Controller.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Variations\\Stats\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Variations/Stats/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Variations\\Stats\\Query' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Variations/Stats/Query.php',
    'Automattic\\WooCommerce\\Admin\\API\\Reports\\Variations\\Stats\\Segmenter' => $baseDir . '/packages/woocommerce-admin/src/API/Reports/Variations/Stats/Segmenter.php',
    'Automattic\\WooCommerce\\Admin\\API\\SettingOptions' => $baseDir . '/packages/woocommerce-admin/src/API/SettingOptions.php',
    'Automattic\\WooCommerce\\Admin\\API\\Taxes' => $baseDir . '/packages/woocommerce-admin/src/API/Taxes.php',
    'Automattic\\WooCommerce\\Admin\\API\\Themes' => $baseDir . '/packages/woocommerce-admin/src/API/Themes.php',
    'Automattic\\WooCommerce\\Admin\\CategoryLookup' => $baseDir . '/packages/woocommerce-admin/src/CategoryLookup.php',
    'Automattic\\WooCommerce\\Admin\\Composer\\Package' => $baseDir . '/packages/woocommerce-admin/src/Composer/Package.php',
    'Automattic\\WooCommerce\\Admin\\DateTimeProvider\\CurrentDateTimeProvider' => $baseDir . '/packages/woocommerce-admin/src/DateTimeProvider/CurrentDateTimeProvider.php',
    'Automattic\\WooCommerce\\Admin\\DateTimeProvider\\DateTimeProviderInterface' => $baseDir . '/packages/woocommerce-admin/src/DateTimeProvider/DateTimeProviderInterface.php',
    'Automattic\\WooCommerce\\Admin\\DeprecatedClassFacade' => $baseDir . '/packages/woocommerce-admin/src/DeprecatedClassFacade.php',
    'Automattic\\WooCommerce\\Admin\\Events' => $baseDir . '/packages/woocommerce-admin/src/Events.php',
    'Automattic\\WooCommerce\\Admin\\FeaturePlugin' => $baseDir . '/packages/woocommerce-admin/src/FeaturePlugin.php',
    'Automattic\\WooCommerce\\Admin\\Features\\ActivityPanels' => $baseDir . '/packages/woocommerce-admin/src/Features/ActivityPanels.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Analytics' => $baseDir . '/packages/woocommerce-admin/src/Features/Analytics.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Coupons' => $baseDir . '/packages/woocommerce-admin/src/Features/Coupons.php',
    'Automattic\\WooCommerce\\Admin\\Features\\CouponsMovedTrait' => $baseDir . '/packages/woocommerce-admin/src/Features/CouponsMovedTrait.php',
    'Automattic\\WooCommerce\\Admin\\Features\\CustomerEffortScoreTracks' => $baseDir . '/packages/woocommerce-admin/src/Features/CustomerEffortScoreTracks.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Features' => $baseDir . '/packages/woocommerce-admin/src/Features/Features.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Homescreen' => $baseDir . '/packages/woocommerce-admin/src/Features/Homescreen.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Marketing' => $baseDir . '/packages/woocommerce-admin/src/Features/Marketing.php',
    'Automattic\\WooCommerce\\Admin\\Features\\MobileAppBanner' => $baseDir . '/packages/woocommerce-admin/src/Features/MobileAppBanner.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Navigation\\CoreMenu' => $baseDir . '/packages/woocommerce-admin/src/Features/Navigation/CoreMenu.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Navigation\\Favorites' => $baseDir . '/packages/woocommerce-admin/src/Features/Navigation/Favorites.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Navigation\\Init' => $baseDir . '/packages/woocommerce-admin/src/Features/Navigation/Init.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Navigation\\Menu' => $baseDir . '/packages/woocommerce-admin/src/Features/Navigation/Menu.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Navigation\\Screen' => $baseDir . '/packages/woocommerce-admin/src/Features/Navigation/Screen.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Onboarding' => $baseDir . '/packages/woocommerce-admin/src/Features/Onboarding.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Init' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Init.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Task' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Task.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\TaskList' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/TaskList.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\TaskLists' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/TaskLists.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\Appearance' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/Appearance.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\Marketing' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/Marketing.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\Payments' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/Payments.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\Products' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/Products.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\Purchase' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/Purchase.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\Shipping' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/Shipping.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\StoreDetails' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/StoreDetails.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\Tax' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/Tax.php',
    'Automattic\\WooCommerce\\Admin\\Features\\OnboardingTasks\\Tasks\\WooCommercePayments' => $baseDir . '/packages/woocommerce-admin/src/Features/OnboardingTasks/Tasks/WooCommercePayments.php',
    'Automattic\\WooCommerce\\Admin\\Features\\PaymentGatewaySuggestions\\DataSourcePoller' => $baseDir . '/packages/woocommerce-admin/src/Features/PaymentGatewaySuggestions/DataSourcePoller.php',
    'Automattic\\WooCommerce\\Admin\\Features\\PaymentGatewaySuggestions\\DefaultPaymentGateways' => $baseDir . '/packages/woocommerce-admin/src/Features/PaymentGatewaySuggestions/DefaultPaymentGateways.php',
    'Automattic\\WooCommerce\\Admin\\Features\\PaymentGatewaySuggestions\\EvaluateSuggestion' => $baseDir . '/packages/woocommerce-admin/src/Features/PaymentGatewaySuggestions/EvaluateSuggestion.php',
    'Automattic\\WooCommerce\\Admin\\Features\\PaymentGatewaySuggestions\\Init' => $baseDir . '/packages/woocommerce-admin/src/Features/PaymentGatewaySuggestions/Init.php',
    'Automattic\\WooCommerce\\Admin\\Features\\PaymentGatewaySuggestions\\PaymentGatewaysController' => $baseDir . '/packages/woocommerce-admin/src/Features/PaymentGatewaySuggestions/PaymentGatewaysController.php',
    'Automattic\\WooCommerce\\Admin\\Features\\RemoteFreeExtensions\\DataSourcePoller' => $baseDir . '/packages/woocommerce-admin/src/Features/RemoteFreeExtensions/DataSourcePoller.php',
    'Automattic\\WooCommerce\\Admin\\Features\\RemoteFreeExtensions\\DefaultFreeExtensions' => $baseDir . '/packages/woocommerce-admin/src/Features/RemoteFreeExtensions/DefaultFreeExtensions.php',
    'Automattic\\WooCommerce\\Admin\\Features\\RemoteFreeExtensions\\EvaluateExtension' => $baseDir . '/packages/woocommerce-admin/src/Features/RemoteFreeExtensions/EvaluateExtension.php',
    'Automattic\\WooCommerce\\Admin\\Features\\RemoteFreeExtensions\\Init' => $baseDir . '/packages/woocommerce-admin/src/Features/RemoteFreeExtensions/Init.php',
    'Automattic\\WooCommerce\\Admin\\Features\\RemoteInboxNotifications' => $baseDir . '/packages/woocommerce-admin/src/Features/RemoteInboxNotifications.php',
    'Automattic\\WooCommerce\\Admin\\Features\\Settings' => $baseDir . '/packages/woocommerce-admin/src/Features/Settings.php',
    'Automattic\\WooCommerce\\Admin\\Features\\ShippingLabelBanner' => $baseDir . '/packages/woocommerce-admin/src/Features/ShippingLabelBanner.php',
    'Automattic\\WooCommerce\\Admin\\Features\\ShippingLabelBannerDisplayRules' => $baseDir . '/packages/woocommerce-admin/src/Features/ShippingLabelBannerDisplayRules.php',
    'Automattic\\WooCommerce\\Admin\\Features\\TransientNotices' => $baseDir . '/packages/woocommerce-admin/src/Features/TransientNotices.php',
    'Automattic\\WooCommerce\\Admin\\Features\\WcPayPromotion\\DataSourcePoller' => $baseDir . '/packages/woocommerce-admin/src/Features/WcPayPromotion/DataSourcePoller.php',
    'Automattic\\WooCommerce\\Admin\\Features\\WcPayPromotion\\Init' => $baseDir . '/packages/woocommerce-admin/src/Features/WcPayPromotion/Init.php',
    'Automattic\\WooCommerce\\Admin\\Features\\WcPayPromotion\\WCPaymentGatewayPreInstallWCPayPromotion' => $baseDir . '/packages/woocommerce-admin/src/Features/WcPayPromotion/WCPaymentGatewayPreInstallWCPayPromotion.php',
    'Automattic\\WooCommerce\\Admin\\Install' => $baseDir . '/packages/woocommerce-admin/src/Install.php',
    'Automattic\\WooCommerce\\Admin\\Loader' => $baseDir . '/packages/woocommerce-admin/src/Loader.php',
    'Automattic\\WooCommerce\\Admin\\Marketing\\InstalledExtensions' => $baseDir . '/packages/woocommerce-admin/src/Marketing/InstalledExtensions.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\AddFirstProduct' => $baseDir . '/packages/woocommerce-admin/src/Notes/AddFirstProduct.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\AddingAndManangingProducts' => $baseDir . '/packages/woocommerce-admin/src/Notes/AddingAndManangingProducts.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\ChooseNiche' => $baseDir . '/packages/woocommerce-admin/src/Notes/ChooseNiche.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\ChoosingTheme' => $baseDir . '/packages/woocommerce-admin/src/Notes/ChoosingTheme.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\CouponPageMoved' => $baseDir . '/packages/woocommerce-admin/src/Notes/CouponPageMoved.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\CustomizeStoreWithBlocks' => $baseDir . '/packages/woocommerce-admin/src/Notes/CustomizeStoreWithBlocks.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\CustomizingProductCatalog' => $baseDir . '/packages/woocommerce-admin/src/Notes/CustomizingProductCatalog.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\DataStore' => $baseDir . '/packages/woocommerce-admin/src/Notes/DataStore.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\DeactivatePlugin' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeactivatePlugin.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\DrawAttention' => $baseDir . '/packages/woocommerce-admin/src/Notes/DrawAttention.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\EUVATNumber' => $baseDir . '/packages/woocommerce-admin/src/Notes/EUVATNumber.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\EditProductsOnTheMove' => $baseDir . '/packages/woocommerce-admin/src/Notes/EditProductsOnTheMove.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\FilterByProductVariationsInReports' => $baseDir . '/packages/woocommerce-admin/src/Notes/FilterByProductVariationsInReports.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\FirstDownlaodableProduct' => $baseDir . '/packages/woocommerce-admin/src/Notes/FirstDownlaodableProduct.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\FirstProduct' => $baseDir . '/packages/woocommerce-admin/src/Notes/FirstProduct.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\GettingStartedInEcommerceWebinar' => $baseDir . '/packages/woocommerce-admin/src/Notes/GettingStartedInEcommerceWebinar.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\GivingFeedbackNotes' => $baseDir . '/packages/woocommerce-admin/src/Notes/GivingFeedbackNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\InsightFirstProductAndPayment' => $baseDir . '/packages/woocommerce-admin/src/Notes/InsightFirstProductAndPayment.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\InsightFirstSale' => $baseDir . '/packages/woocommerce-admin/src/Notes/InsightFirstSale.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\InstallJPAndWCSPlugins' => $baseDir . '/packages/woocommerce-admin/src/Notes/InstallJPAndWCSPlugins.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\LaunchChecklist' => $baseDir . '/packages/woocommerce-admin/src/Notes/LaunchChecklist.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\LearnMoreAboutVariableProducts' => $baseDir . '/packages/woocommerce-admin/src/Notes/LearnMoreAboutVariableProducts.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\ManageOrdersOnTheGo' => $baseDir . '/packages/woocommerce-admin/src/Notes/ManageOrdersOnTheGo.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\ManageStoreActivityFromHomeScreen' => $baseDir . '/packages/woocommerce-admin/src/Notes/ManageStoreActivityFromHomeScreen.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\Marketing' => $baseDir . '/packages/woocommerce-admin/src/Notes/Marketing.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\MarketingJetpack' => $baseDir . '/packages/woocommerce-admin/src/Notes/MarketingJetpack.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\MerchantEmailNotifications\\MerchantEmailNotifications' => $baseDir . '/packages/woocommerce-admin/src/Notes/MerchantEmailNotifications/MerchantEmailNotifications.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\MerchantEmailNotifications\\NotificationEmail' => $baseDir . '/packages/woocommerce-admin/src/Notes/MerchantEmailNotifications/NotificationEmail.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\MigrateFromShopify' => $baseDir . '/packages/woocommerce-admin/src/Notes/MigrateFromShopify.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\MobileApp' => $baseDir . '/packages/woocommerce-admin/src/Notes/MobileApp.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\NavigationFeedback' => $baseDir . '/packages/woocommerce-admin/src/Notes/NavigationFeedback.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\NavigationFeedbackFollowUp' => $baseDir . '/packages/woocommerce-admin/src/Notes/NavigationFeedbackFollowUp.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\NavigationNudge' => $baseDir . '/packages/woocommerce-admin/src/Notes/NavigationNudge.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\NeedSomeInspiration' => $baseDir . '/packages/woocommerce-admin/src/Notes/NeedSomeInspiration.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\NewSalesRecord' => $baseDir . '/packages/woocommerce-admin/src/Notes/NewSalesRecord.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\Note' => $baseDir . '/packages/woocommerce-admin/src/Notes/Note.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\NoteTraits' => $baseDir . '/packages/woocommerce-admin/src/Notes/NoteTraits.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\Notes' => $baseDir . '/packages/woocommerce-admin/src/Notes/Notes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\NotesUnavailableException' => $baseDir . '/packages/woocommerce-admin/src/Notes/NotesUnavailableException.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\OnboardingPayments' => $baseDir . '/packages/woocommerce-admin/src/Notes/OnboardingPayments.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\OnboardingTraits' => $baseDir . '/packages/woocommerce-admin/src/Notes/OnboardingTraits.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\OnlineClothingStore' => $baseDir . '/packages/woocommerce-admin/src/Notes/OnlineClothingStore.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\OrderMilestones' => $baseDir . '/packages/woocommerce-admin/src/Notes/OrderMilestones.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\PerformanceOnMobile' => $baseDir . '/packages/woocommerce-admin/src/Notes/PerformanceOnMobile.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\PersonalizeStore' => $baseDir . '/packages/woocommerce-admin/src/Notes/PersonalizeStore.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\RealTimeOrderAlerts' => $baseDir . '/packages/woocommerce-admin/src/Notes/RealTimeOrderAlerts.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\SellingOnlineCourses' => $baseDir . '/packages/woocommerce-admin/src/Notes/SellingOnlineCourses.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\SetUpAdditionalPaymentTypes' => $baseDir . '/packages/woocommerce-admin/src/Notes/SetUpAdditionalPaymentTypes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\StartDropshippingBusiness' => $baseDir . '/packages/woocommerce-admin/src/Notes/StartDropshippingBusiness.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\TestCheckout' => $baseDir . '/packages/woocommerce-admin/src/Notes/TestCheckout.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\TrackingOptIn' => $baseDir . '/packages/woocommerce-admin/src/Notes/TrackingOptIn.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\UnsecuredReportFiles' => $baseDir . '/packages/woocommerce-admin/src/Notes/UnsecuredReportFiles.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Note' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Choose_Niche' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Coupon_Page_Moved' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Customize_Store_With_Blocks' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Deactivate_Plugin' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Draw_Attention' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_EU_VAT_Number' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Edit_Products_On_The_Move' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Facebook_Marketing_Expert' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_First_Product' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Giving_Feedback_Notes' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Insight_First_Sale' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Install_JP_And_WCS_Plugins' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Launch_Checklist' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Marketing' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Migrate_From_Shopify' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Mobile_App' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Need_Some_Inspiration' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_New_Sales_Record' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Onboarding_Email_Marketing' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Onboarding_Payments' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Online_Clothing_Store' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Order_Milestones' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Performance_On_Mobile' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Personalize_Store' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Real_Time_Order_Alerts' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Selling_Online_Courses' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Set_Up_Additional_Payment_Types' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Start_Dropshipping_Business' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Test_Checkout' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Tracking_Opt_In' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_WooCommerce_Payments' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_WooCommerce_Subscriptions' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WC_Admin_Notes_Woo_Subscriptions_Notes' => $baseDir . '/packages/woocommerce-admin/src/Notes/DeprecatedNotes.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WelcomeToWooCommerceForStoreUsers' => $baseDir . '/packages/woocommerce-admin/src/Notes/WelcomeToWooCommerceForStoreUsers.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WooCommercePayments' => $baseDir . '/packages/woocommerce-admin/src/Notes/WooCommercePayments.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WooCommerceSubscriptions' => $baseDir . '/packages/woocommerce-admin/src/Notes/WooCommerceSubscriptions.php',
    'Automattic\\WooCommerce\\Admin\\Notes\\WooSubscriptionsNotes' => $baseDir . '/packages/woocommerce-admin/src/Notes/WooSubscriptionsNotes.php',
    'Automattic\\WooCommerce\\Admin\\Overrides\\Order' => $baseDir . '/packages/woocommerce-admin/src/Overrides/Order.php',
    'Automattic\\WooCommerce\\Admin\\Overrides\\OrderRefund' => $baseDir . '/packages/woocommerce-admin/src/Overrides/OrderRefund.php',
    'Automattic\\WooCommerce\\Admin\\Overrides\\OrderTraits' => $baseDir . '/packages/woocommerce-admin/src/Overrides/OrderTraits.php',
    'Automattic\\WooCommerce\\Admin\\Overrides\\ThemeUpgrader' => $baseDir . '/packages/woocommerce-admin/src/Overrides/ThemeUpgrader.php',
    'Automattic\\WooCommerce\\Admin\\Overrides\\ThemeUpgraderSkin' => $baseDir . '/packages/woocommerce-admin/src/Overrides/ThemeUpgraderSkin.php',
    'Automattic\\WooCommerce\\Admin\\PageController' => $baseDir . '/packages/woocommerce-admin/src/PageController.php',
    'Automattic\\WooCommerce\\Admin\\PaymentPlugins' => $baseDir . '/packages/woocommerce-admin/src/PaymentPlugins.php',
    'Automattic\\WooCommerce\\Admin\\PluginsHelper' => $baseDir . '/packages/woocommerce-admin/src/PluginsHelper.php',
    'Automattic\\WooCommerce\\Admin\\PluginsInstaller' => $baseDir . '/packages/woocommerce-admin/src/PluginsInstaller.php',
    'Automattic\\WooCommerce\\Admin\\PluginsProvider\\PluginsProvider' => $baseDir . '/packages/woocommerce-admin/src/PluginsProvider/PluginsProvider.php',
    'Automattic\\WooCommerce\\Admin\\PluginsProvider\\PluginsProviderInterface' => $baseDir . '/packages/woocommerce-admin/src/PluginsProvider/PluginsProviderInterface.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\BaseLocationCountryRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/BaseLocationCountryRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\BaseLocationStateRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/BaseLocationStateRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\ComparisonOperation' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/ComparisonOperation.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\DataSourcePoller' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/DataSourcePoller.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\EvaluateAndGetStatus' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/EvaluateAndGetStatus.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\EvaluationLogger' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/EvaluationLogger.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\FailRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/FailRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\GetRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/GetRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\IsEcommerceRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/IsEcommerceRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\NotRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/NotRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\NoteStatusRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/NoteStatusRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\OnboardingProfileRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/OnboardingProfileRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\OptionRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/OptionRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\OrRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/OrRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\OrderCountRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/OrderCountRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\OrdersProvider' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/OrdersProvider.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\PassRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/PassRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\PluginVersionRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/PluginVersionRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\PluginsActivatedRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/PluginsActivatedRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\ProductCountRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/ProductCountRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\PublishAfterTimeRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/PublishAfterTimeRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\PublishBeforeTimeRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/PublishBeforeTimeRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\RemoteInboxNotificationsEngine' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/RemoteInboxNotificationsEngine.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\RuleEvaluator' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/RuleEvaluator.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\RuleProcessorInterface' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/RuleProcessorInterface.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\SpecRunner' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/SpecRunner.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\StoredStateRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/StoredStateRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\StoredStateSetupForProducts' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/StoredStateSetupForProducts.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\TransformerInterface' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/TransformerInterface.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\TransformerService' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/TransformerService.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\Transformers\\ArrayColumn' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/Transformers/ArrayColumn.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\Transformers\\ArrayFlatten' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/Transformers/ArrayFlatten.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\Transformers\\ArrayKeys' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/Transformers/ArrayKeys.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\Transformers\\ArraySearch' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/Transformers/ArraySearch.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\Transformers\\ArrayValues' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/Transformers/ArrayValues.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\Transformers\\Count' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/Transformers/Count.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\Transformers\\DotNotation' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/Transformers/DotNotation.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\WCAdminActiveForProvider' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/WCAdminActiveForProvider.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\WCAdminActiveForRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/WCAdminActiveForRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\RemoteInboxNotifications\\WooCommerceAdminUpdatedRuleProcessor' => $baseDir . '/packages/woocommerce-admin/src/RemoteInboxNotifications/WooCommerceAdminUpdatedRuleProcessor.php',
    'Automattic\\WooCommerce\\Admin\\ReportCSVEmail' => $baseDir . '/packages/woocommerce-admin/src/ReportCSVEmail.php',
    'Automattic\\WooCommerce\\Admin\\ReportCSVExporter' => $baseDir . '/packages/woocommerce-admin/src/ReportCSVExporter.php',
    'Automattic\\WooCommerce\\Admin\\ReportExporter' => $baseDir . '/packages/woocommerce-admin/src/ReportExporter.php',
    'Automattic\\WooCommerce\\Admin\\ReportsSync' => $baseDir . '/packages/woocommerce-admin/src/ReportsSync.php',
    'Automattic\\WooCommerce\\Admin\\Schedulers\\CustomersScheduler' => $baseDir . '/packages/woocommerce-admin/src/Schedulers/CustomersScheduler.php',
    'Automattic\\WooCommerce\\Admin\\Schedulers\\ImportInterface' => $baseDir . '/packages/woocommerce-admin/src/Schedulers/ImportInterface.php',
    'Automattic\\WooCommerce\\Admin\\Schedulers\\ImportScheduler' => $baseDir . '/packages/woocommerce-admin/src/Schedulers/ImportScheduler.php',
    'Automattic\\WooCommerce\\Admin\\Schedulers\\MailchimpScheduler' => $baseDir . '/packages/woocommerce-admin/src/Schedulers/MailchimpScheduler.php',
    'Automattic\\WooCommerce\\Admin\\Schedulers\\OrdersScheduler' => $baseDir . '/packages/woocommerce-admin/src/Schedulers/OrdersScheduler.php',
    'Automattic\\WooCommerce\\Admin\\Schedulers\\SchedulerTraits' => $baseDir . '/packages/woocommerce-admin/src/Schedulers/SchedulerTraits.php',
    'Automattic\\WooCommerce\\Admin\\Survey' => $baseDir . '/packages/woocommerce-admin/src/Survey.php',
    'Automattic\\WooCommerce\\Admin\\WCAdminHelper' => $baseDir . '/packages/woocommerce-admin/src/WCAdminHelper.php',
    'Automattic\\WooCommerce\\Admin\\WCAdminSharedSettings' => $baseDir . '/packages/woocommerce-admin/src/WCAdminSharedSettings.php',
    'Automattic\\WooCommerce\\Autoloader' => $baseDir . '/src/Autoloader.php',
    'Automattic\\WooCommerce\\Blocks\\Assets' => $baseDir . '/packages/woocommerce-blocks/src/Assets.php',
    'Automattic\\WooCommerce\\Blocks\\AssetsController' => $baseDir . '/packages/woocommerce-blocks/src/AssetsController.php',
    'Automattic\\WooCommerce\\Blocks\\Assets\\Api' => $baseDir . '/packages/woocommerce-blocks/src/Assets/Api.php',
    'Automattic\\WooCommerce\\Blocks\\Assets\\AssetDataRegistry' => $baseDir . '/packages/woocommerce-blocks/src/Assets/AssetDataRegistry.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypesController' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypesController.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\AbstractBlock' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/AbstractBlock.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\AbstractDynamicBlock' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/AbstractDynamicBlock.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\AbstractProductGrid' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/AbstractProductGrid.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ActiveFilters' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ActiveFilters.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\AllProducts' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/AllProducts.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\AllReviews' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/AllReviews.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\AtomicBlock' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/AtomicBlock.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\AttributeFilter' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/AttributeFilter.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\Cart' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/Cart.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\CartI2' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/CartI2.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\Checkout' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/Checkout.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\FeaturedCategory' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/FeaturedCategory.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\FeaturedProduct' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/FeaturedProduct.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\HandpickedProducts' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/HandpickedProducts.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\MiniCart' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/MiniCart.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\PriceFilter' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/PriceFilter.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductBestSellers' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductBestSellers.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductCategories' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductCategories.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductCategory' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductCategory.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductNew' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductNew.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductOnSale' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductOnSale.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductSearch' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductSearch.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductTag' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductTag.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductTopRated' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductTopRated.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ProductsByAttribute' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ProductsByAttribute.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ReviewsByCategory' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ReviewsByCategory.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\ReviewsByProduct' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/ReviewsByProduct.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\SingleProduct' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/SingleProduct.php',
    'Automattic\\WooCommerce\\Blocks\\BlockTypes\\StockFilter' => $baseDir . '/packages/woocommerce-blocks/src/BlockTypes/StockFilter.php',
    'Automattic\\WooCommerce\\Blocks\\Domain\\Bootstrap' => $baseDir . '/packages/woocommerce-blocks/src/Domain/Bootstrap.php',
    'Automattic\\WooCommerce\\Blocks\\Domain\\Package' => $baseDir . '/packages/woocommerce-blocks/src/Domain/Package.php',
    'Automattic\\WooCommerce\\Blocks\\Domain\\Services\\CreateAccount' => $baseDir . '/packages/woocommerce-blocks/src/Domain/Services/CreateAccount.php',
    'Automattic\\WooCommerce\\Blocks\\Domain\\Services\\DraftOrders' => $baseDir . '/packages/woocommerce-blocks/src/Domain/Services/DraftOrders.php',
    'Automattic\\WooCommerce\\Blocks\\Domain\\Services\\Email\\CustomerNewAccount' => $baseDir . '/packages/woocommerce-blocks/src/Domain/Services/Email/CustomerNewAccount.php',
    'Automattic\\WooCommerce\\Blocks\\Domain\\Services\\ExtendRestApi' => $baseDir . '/packages/woocommerce-blocks/src/Domain/Services/ExtendRestApi.php',
    'Automattic\\WooCommerce\\Blocks\\Domain\\Services\\FeatureGating' => $baseDir . '/packages/woocommerce-blocks/src/Domain/Services/FeatureGating.php',
    'Automattic\\WooCommerce\\Blocks\\Domain\\Services\\GoogleAnalytics' => $baseDir . '/packages/woocommerce-blocks/src/Domain/Services/GoogleAnalytics.php',
    'Automattic\\WooCommerce\\Blocks\\InboxNotifications' => $baseDir . '/packages/woocommerce-blocks/src/InboxNotifications.php',
    'Automattic\\WooCommerce\\Blocks\\Installer' => $baseDir . '/packages/woocommerce-blocks/src/Installer.php',
    'Automattic\\WooCommerce\\Blocks\\Integrations\\IntegrationInterface' => $baseDir . '/packages/woocommerce-blocks/src/Integrations/IntegrationInterface.php',
    'Automattic\\WooCommerce\\Blocks\\Integrations\\IntegrationRegistry' => $baseDir . '/packages/woocommerce-blocks/src/Integrations/IntegrationRegistry.php',
    'Automattic\\WooCommerce\\Blocks\\Library' => $baseDir . '/packages/woocommerce-blocks/src/Library.php',
    'Automattic\\WooCommerce\\Blocks\\Package' => $baseDir . '/packages/woocommerce-blocks/src/Package.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\Api' => $baseDir . '/packages/woocommerce-blocks/src/Payments/Api.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\Integrations\\AbstractPaymentMethodType' => $baseDir . '/packages/woocommerce-blocks/src/Payments/Integrations/AbstractPaymentMethodType.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\Integrations\\BankTransfer' => $baseDir . '/packages/woocommerce-blocks/src/Payments/Integrations/BankTransfer.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\Integrations\\CashOnDelivery' => $baseDir . '/packages/woocommerce-blocks/src/Payments/Integrations/CashOnDelivery.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\Integrations\\Cheque' => $baseDir . '/packages/woocommerce-blocks/src/Payments/Integrations/Cheque.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\Integrations\\PayPal' => $baseDir . '/packages/woocommerce-blocks/src/Payments/Integrations/PayPal.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\Integrations\\Stripe' => $baseDir . '/packages/woocommerce-blocks/src/Payments/Integrations/Stripe.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\PaymentContext' => $baseDir . '/packages/woocommerce-blocks/src/Payments/PaymentContext.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\PaymentMethodRegistry' => $baseDir . '/packages/woocommerce-blocks/src/Payments/PaymentMethodRegistry.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\PaymentMethodTypeInterface' => $baseDir . '/packages/woocommerce-blocks/src/Payments/PaymentMethodTypeInterface.php',
    'Automattic\\WooCommerce\\Blocks\\Payments\\PaymentResult' => $baseDir . '/packages/woocommerce-blocks/src/Payments/PaymentResult.php',
    'Automattic\\WooCommerce\\Blocks\\Registry\\AbstractDependencyType' => $baseDir . '/packages/woocommerce-blocks/src/Registry/AbstractDependencyType.php',
    'Automattic\\WooCommerce\\Blocks\\Registry\\Container' => $baseDir . '/packages/woocommerce-blocks/src/Registry/Container.php',
    'Automattic\\WooCommerce\\Blocks\\Registry\\FactoryType' => $baseDir . '/packages/woocommerce-blocks/src/Registry/FactoryType.php',
    'Automattic\\WooCommerce\\Blocks\\Registry\\SharedType' => $baseDir . '/packages/woocommerce-blocks/src/Registry/SharedType.php',
    'Automattic\\WooCommerce\\Blocks\\RestApi' => $baseDir . '/packages/woocommerce-blocks/src/RestApi.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Formatters' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Formatters.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Formatters\\CurrencyFormatter' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Formatters/CurrencyFormatter.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Formatters\\DefaultFormatter' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Formatters/DefaultFormatter.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Formatters\\FormatterInterface' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Formatters/FormatterInterface.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Formatters\\HtmlFormatter' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Formatters/HtmlFormatter.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Formatters\\MoneyFormatter' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Formatters/MoneyFormatter.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\RoutesController' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/RoutesController.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\AbstractCartRoute' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/AbstractCartRoute.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\AbstractRoute' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/AbstractRoute.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\AbstractTermsRoute' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/AbstractTermsRoute.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\Batch' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/Batch.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\Cart' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/Cart.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartAddItem' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartAddItem.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartApplyCoupon' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartApplyCoupon.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartCoupons' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartCoupons.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartCouponsByCode' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartCouponsByCode.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartExtensions' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartExtensions.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartItems' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartItems.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartItemsByKey' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartItemsByKey.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartRemoveCoupon' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartRemoveCoupon.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartRemoveItem' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartRemoveItem.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartSelectShippingRate' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartSelectShippingRate.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartUpdateCustomer' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartUpdateCustomer.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\CartUpdateItem' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/CartUpdateItem.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\Checkout' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/Checkout.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductAttributeTerms' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductAttributeTerms.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductAttributes' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductAttributes.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductAttributesById' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductAttributesById.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductCategories' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductCategories.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductCategoriesById' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductCategoriesById.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductCollectionData' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductCollectionData.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductReviews' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductReviews.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductTags' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductTags.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\Products' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/Products.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\ProductsById' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/ProductsById.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\RouteException' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/RouteException.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Routes\\RouteInterface' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Routes/RouteInterface.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\SchemaController' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/SchemaController.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\AbstractAddressSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/AbstractAddressSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\AbstractSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/AbstractSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\BillingAddressSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/BillingAddressSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\CartCouponSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/CartCouponSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\CartExtensionsSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/CartExtensionsSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\CartFeeSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/CartFeeSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\CartItemSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/CartItemSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\CartSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/CartSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\CartShippingRateSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/CartShippingRateSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\CheckoutSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/CheckoutSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\ErrorSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/ErrorSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\ImageAttachmentSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/ImageAttachmentSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\OrderCouponSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/OrderCouponSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\ProductAttributeSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/ProductAttributeSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\ProductCategorySchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/ProductCategorySchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\ProductCollectionDataSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/ProductCollectionDataSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\ProductReviewSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/ProductReviewSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\ProductSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/ProductSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\ShippingAddressSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/ShippingAddressSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Schemas\\TermSchema' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Schemas/TermSchema.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\CartController' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/CartController.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\InvalidStockLevelsInCartException' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/InvalidStockLevelsInCartException.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\NotPurchasableException' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/NotPurchasableException.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\NoticeHandler' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/NoticeHandler.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\OrderController' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/OrderController.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\OutOfStockException' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/OutOfStockException.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\Pagination' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/Pagination.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\PartialOutOfStockException' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/PartialOutOfStockException.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\ProductQuery' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/ProductQuery.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\ProductQueryFilters' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/ProductQueryFilters.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\StockAvailabilityException' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/StockAvailabilityException.php',
    'Automattic\\WooCommerce\\Blocks\\StoreApi\\Utilities\\TooManyInCartException' => $baseDir . '/packages/woocommerce-blocks/src/StoreApi/Utilities/TooManyInCartException.php',
    'Automattic\\WooCommerce\\Blocks\\Utils\\ArrayUtils' => $baseDir . '/packages/woocommerce-blocks/src/Utils/ArrayUtils.php',
    'Automattic\\WooCommerce\\Blocks\\Utils\\BlocksWpQuery' => $baseDir . '/packages/woocommerce-blocks/src/Utils/BlocksWpQuery.php',
    'Automattic\\WooCommerce\\Checkout\\Helpers\\ReserveStock' => $baseDir . '/src/Checkout/Helpers/ReserveStock.php',
    'Automattic\\WooCommerce\\Checkout\\Helpers\\ReserveStockException' => $baseDir . '/src/Checkout/Helpers/ReserveStockException.php',
    'Automattic\\WooCommerce\\Container' => $baseDir . '/src/Container.php',
    'Automattic\\WooCommerce\\Internal\\AssignDefaultCategory' => $baseDir . '/src/Internal/AssignDefaultCategory.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\AbstractServiceProvider' => $baseDir . '/src/Internal/DependencyManagement/AbstractServiceProvider.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\ContainerException' => $baseDir . '/src/Internal/DependencyManagement/ContainerException.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\Definition' => $baseDir . '/src/Internal/DependencyManagement/Definition.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\ExtendedContainer' => $baseDir . '/src/Internal/DependencyManagement/ExtendedContainer.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\ServiceProviders\\AssignDefaultCategoryServiceProvider' => $baseDir . '/src/Internal/DependencyManagement/ServiceProviders/AssignDefaultCategoryServiceProvider.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\ServiceProviders\\DownloadPermissionsAdjusterServiceProvider' => $baseDir . '/src/Internal/DependencyManagement/ServiceProviders/DownloadPermissionsAdjusterServiceProvider.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\ServiceProviders\\ProductAttributesLookupServiceProvider' => $baseDir . '/src/Internal/DependencyManagement/ServiceProviders/ProductAttributesLookupServiceProvider.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\ServiceProviders\\ProxiesServiceProvider' => $baseDir . '/src/Internal/DependencyManagement/ServiceProviders/ProxiesServiceProvider.php',
    'Automattic\\WooCommerce\\Internal\\DependencyManagement\\ServiceProviders\\RestockRefundedItemsAdjusterServiceProvider' => $baseDir . '/src/Internal/DependencyManagement/ServiceProviders/RestockRefundedItemsAdjusterServiceProvider.php',
    'Automattic\\WooCommerce\\Internal\\DownloadPermissionsAdjuster' => $baseDir . '/src/Internal/DownloadPermissionsAdjuster.php',
    'Automattic\\WooCommerce\\Internal\\ProductAttributesLookup\\DataRegenerator' => $baseDir . '/src/Internal/ProductAttributesLookup/DataRegenerator.php',
    'Automattic\\WooCommerce\\Internal\\ProductAttributesLookup\\Filterer' => $baseDir . '/src/Internal/ProductAttributesLookup/Filterer.php',
    'Automattic\\WooCommerce\\Internal\\ProductAttributesLookup\\LookupDataStore' => $baseDir . '/src/Internal/ProductAttributesLookup/LookupDataStore.php',
    'Automattic\\WooCommerce\\Internal\\RestApiUtil' => $baseDir . '/src/Internal/RestApiUtil.php',
    'Automattic\\WooCommerce\\Internal\\RestockRefundedItemsAdjuster' => $baseDir . '/src/Internal/RestockRefundedItemsAdjuster.php',
    'Automattic\\WooCommerce\\Internal\\WCCom\\ConnectionHelper' => $baseDir . '/src/Internal/WCCom/ConnectionHelper.php',
    'Automattic\\WooCommerce\\Packages' => $baseDir . '/src/Packages.php',
    'Automattic\\WooCommerce\\Proxies\\ActionsProxy' => $baseDir . '/src/Proxies/ActionsProxy.php',
    'Automattic\\WooCommerce\\Proxies\\LegacyProxy' => $baseDir . '/src/Proxies/LegacyProxy.php',
    'Automattic\\WooCommerce\\RestApi\\Package' => $baseDir . '/includes/rest-api/Package.php',
    'Automattic\\WooCommerce\\RestApi\\Server' => $baseDir . '/includes/rest-api/Server.php',
    'Automattic\\WooCommerce\\RestApi\\UnitTests\\Helpers\\AdminNotesHelper' => $baseDir . '/tests/legacy/unit-tests/rest-api/Helpers/AdminNotesHelper.php',
    'Automattic\\WooCommerce\\RestApi\\UnitTests\\Helpers\\CouponHelper' => $baseDir . '/tests/legacy/unit-tests/rest-api/Helpers/CouponHelper.php',
    'Automattic\\WooCommerce\\RestApi\\UnitTests\\Helpers\\CustomerHelper' => $baseDir . '/tests/legacy/unit-tests/rest-api/Helpers/CustomerHelper.php',
    'Automattic\\WooCommerce\\RestApi\\UnitTests\\Helpers\\OrderHelper' => $baseDir . '/tests/legacy/unit-tests/rest-api/Helpers/OrderHelper.php',
    'Automattic\\WooCommerce\\RestApi\\UnitTests\\Helpers\\ProductHelper' => $baseDir . '/tests/legacy/unit-tests/rest-api/Helpers/ProductHelper.php',
    'Automattic\\WooCommerce\\RestApi\\UnitTests\\Helpers\\QueueHelper' => $baseDir . '/tests/legacy/unit-tests/rest-api/Helpers/QueueHelper.php',
    'Automattic\\WooCommerce\\RestApi\\UnitTests\\Helpers\\SettingsHelper' => $baseDir . '/tests/legacy/unit-tests/rest-api/Helpers/SettingsHelper.php',
    'Automattic\\WooCommerce\\RestApi\\UnitTests\\Helpers\\ShippingHelper' => $baseDir . '/tests/legacy/unit-tests/rest-api/Helpers/ShippingHelper.php',
    'Automattic\\WooCommerce\\RestApi\\Utilities\\ImageAttachment' => $baseDir . '/includes/rest-api/Utilities/ImageAttachment.php',
    'Automattic\\WooCommerce\\RestApi\\Utilities\\SingletonTrait' => $baseDir . '/includes/rest-api/Utilities/SingletonTrait.php',
    'Automattic\\WooCommerce\\Testing\\Tools\\CodeHacking\\CodeHacker' => $baseDir . '/tests/Tools/CodeHacking/CodeHacker.php',
    'Automattic\\WooCommerce\\Testing\\Tools\\CodeHacking\\Hacks\\BypassFinalsHack' => $baseDir . '/tests/Tools/CodeHacking/Hacks/BypassFinalsHack.php',
    'Automattic\\WooCommerce\\Testing\\Tools\\CodeHacking\\Hacks\\CodeHack' => $baseDir . '/tests/Tools/CodeHacking/Hacks/CodeHack.php',
    'Automattic\\WooCommerce\\Testing\\Tools\\CodeHacking\\Hacks\\FunctionsMockerHack' => $baseDir . '/tests/Tools/CodeHacking/Hacks/FunctionsMockerHack.php',
    'Automattic\\WooCommerce\\Testing\\Tools\\CodeHacking\\Hacks\\StaticMockerHack' => $baseDir . '/tests/Tools/CodeHacking/Hacks/StaticMockerHack.php',
    'Automattic\\WooCommerce\\Testing\\Tools\\DependencyManagement\\MockableLegacyProxy' => $baseDir . '/tests/Tools/DependencyManagement/MockableLegacyProxy.php',
    'Automattic\\WooCommerce\\Testing\\Tools\\FakeQueue' => $baseDir . '/tests/Tools/FakeQueue.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\AssignDefaultCategoryTest' => $baseDir . '/tests/php/src/Internal/AssignDefaultCategoryTest.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DependencyManagement\\AbstractServiceProviderTest' => $baseDir . '/tests/php/src/Internal/DependencyManagement/AbstractServiceProviderTest.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DependencyManagement\\ExampleClasses\\ClassWithDependencies' => $baseDir . '/tests/php/src/Internal/DependencyManagement/ExampleClasses/ClassWithDependencies.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DependencyManagement\\ExampleClasses\\ClassWithInjectionMethodArgumentWithoutTypeHint' => $baseDir . '/tests/php/src/Internal/DependencyManagement/ExampleClasses/ClassWithInjectionMethodArgumentWithoutTypeHint.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DependencyManagement\\ExampleClasses\\ClassWithNonFinalInjectionMethod' => $baseDir . '/tests/php/src/Internal/DependencyManagement/ExampleClasses/ClassWithNonFinalInjectionMethod.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DependencyManagement\\ExampleClasses\\ClassWithPrivateInjectionMethod' => $baseDir . '/tests/php/src/Internal/DependencyManagement/ExampleClasses/ClassWithPrivateInjectionMethod.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DependencyManagement\\ExampleClasses\\ClassWithScalarInjectionMethodArgument' => $baseDir . '/tests/php/src/Internal/DependencyManagement/ExampleClasses/ClassWithScalarInjectionMethodArgument.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DependencyManagement\\ExampleClasses\\DependencyClass' => $baseDir . '/tests/php/src/Internal/DependencyManagement/ExampleClasses/DependencyClass.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DependencyManagement\\ExtendedContainerTest' => $baseDir . '/tests/php/src/Internal/DependencyManagement/ExtendedContainerTest.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\DownloadPermissionsAdjusterTest' => $baseDir . '/tests/php/src/Internal/DownloadPermissionsAdjusterTest.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\ProductAttributesLookup\\DataRegeneratorTest' => $baseDir . '/tests/php/src/Internal/ProductAttributesLookup/DataRegeneratorTest.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\ProductAttributesLookup\\FiltererTest' => $baseDir . '/tests/php/src/Internal/ProductAttributesLookup/FiltererTest.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\ProductAttributesLookup\\LookupDataStoreTest' => $baseDir . '/tests/php/src/Internal/ProductAttributesLookup/LookupDataStoreTest.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\RestApiUtilTest' => $baseDir . '/tests/php/src/Internal/RestApiUtilTest.php',
    'Automattic\\WooCommerce\\Tests\\Internal\\WCCom\\ConnectionHelperTest' => $baseDir . '/tests/php/src/Internal/WCCom/ConnectionHelperTest.php',
    'Automattic\\WooCommerce\\Tests\\Proxies\\ClassThatDependsOnLegacyCodeTest' => $baseDir . '/tests/php/src/Proxies/ClassThatDependsOnLegacyCodeTest.php',
    'Automattic\\WooCommerce\\Tests\\Proxies\\ExampleClasses\\ClassThatDependsOnLegacyCode' => $baseDir . '/tests/php/src/Proxies/ExampleClasses/ClassThatDependsOnLegacyCode.php',
    'Automattic\\WooCommerce\\Tests\\Proxies\\LegacyProxyTest' => $baseDir . '/tests/php/src/Proxies/LegacyProxyTest.php',
    'Automattic\\WooCommerce\\Tests\\Proxies\\MockableLegacyProxyTest' => $baseDir . '/tests/php/src/Proxies/MockableLegacyProxyTest.php',
    'Automattic\\WooCommerce\\Tests\\Utilities\\ArrayUtilTest' => $baseDir . '/tests/php/src/Utilities/ArrayUtilTest.php',
    'Automattic\\WooCommerce\\Tests\\Utilities\\NumberUtilTest' => $baseDir . '/tests/php/src/Utilities/NumberUtilTest.php',
    'Automattic\\WooCommerce\\Tests\\Utilities\\StringUtilTest' => $baseDir . '/tests/php/src/Utilities/StringUtilTest.php',
    'Automattic\\WooCommerce\\Utilities\\ArrayUtil' => $baseDir . '/src/Utilities/ArrayUtil.php',
    'Automattic\\WooCommerce\\Utilities\\NumberUtil' => $baseDir . '/src/Utilities/NumberUtil.php',
    'Automattic\\WooCommerce\\Utilities\\StringUtil' => $baseDir . '/src/Utilities/StringUtil.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Argument\\ArgumentResolverInterface' => $baseDir . '/lib/packages/League/Container/Argument/ArgumentResolverInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Argument\\ArgumentResolverTrait' => $baseDir . '/lib/packages/League/Container/Argument/ArgumentResolverTrait.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Argument\\ClassName' => $baseDir . '/lib/packages/League/Container/Argument/ClassName.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Argument\\ClassNameInterface' => $baseDir . '/lib/packages/League/Container/Argument/ClassNameInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Argument\\ClassNameWithOptionalValue' => $baseDir . '/lib/packages/League/Container/Argument/ClassNameWithOptionalValue.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Argument\\RawArgument' => $baseDir . '/lib/packages/League/Container/Argument/RawArgument.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Argument\\RawArgumentInterface' => $baseDir . '/lib/packages/League/Container/Argument/RawArgumentInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Container' => $baseDir . '/lib/packages/League/Container/Container.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\ContainerAwareInterface' => $baseDir . '/lib/packages/League/Container/ContainerAwareInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\ContainerAwareTrait' => $baseDir . '/lib/packages/League/Container/ContainerAwareTrait.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Definition\\Definition' => $baseDir . '/lib/packages/League/Container/Definition/Definition.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Definition\\DefinitionAggregate' => $baseDir . '/lib/packages/League/Container/Definition/DefinitionAggregate.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Definition\\DefinitionAggregateInterface' => $baseDir . '/lib/packages/League/Container/Definition/DefinitionAggregateInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Definition\\DefinitionInterface' => $baseDir . '/lib/packages/League/Container/Definition/DefinitionInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Exception\\ContainerException' => $baseDir . '/lib/packages/League/Container/Exception/ContainerException.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Exception\\NotFoundException' => $baseDir . '/lib/packages/League/Container/Exception/NotFoundException.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Inflector\\Inflector' => $baseDir . '/lib/packages/League/Container/Inflector/Inflector.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Inflector\\InflectorAggregate' => $baseDir . '/lib/packages/League/Container/Inflector/InflectorAggregate.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Inflector\\InflectorAggregateInterface' => $baseDir . '/lib/packages/League/Container/Inflector/InflectorAggregateInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\Inflector\\InflectorInterface' => $baseDir . '/lib/packages/League/Container/Inflector/InflectorInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\ReflectionContainer' => $baseDir . '/lib/packages/League/Container/ReflectionContainer.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\ServiceProvider\\AbstractServiceProvider' => $baseDir . '/lib/packages/League/Container/ServiceProvider/AbstractServiceProvider.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\ServiceProvider\\BootableServiceProviderInterface' => $baseDir . '/lib/packages/League/Container/ServiceProvider/BootableServiceProviderInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\ServiceProvider\\ServiceProviderAggregate' => $baseDir . '/lib/packages/League/Container/ServiceProvider/ServiceProviderAggregate.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\ServiceProvider\\ServiceProviderAggregateInterface' => $baseDir . '/lib/packages/League/Container/ServiceProvider/ServiceProviderAggregateInterface.php',
    'Automattic\\WooCommerce\\Vendor\\League\\Container\\ServiceProvider\\ServiceProviderInterface' => $baseDir . '/lib/packages/League/Container/ServiceProvider/ServiceProviderInterface.php',
    'Composer\\Installers\\AglInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AglInstaller.php',
    'Composer\\Installers\\AimeosInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AimeosInstaller.php',
    'Composer\\Installers\\AnnotateCmsInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AnnotateCmsInstaller.php',
    'Composer\\Installers\\AsgardInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AsgardInstaller.php',
    'Composer\\Installers\\AttogramInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AttogramInstaller.php',
    'Composer\\Installers\\BaseInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/BaseInstaller.php',
    'Composer\\Installers\\BitrixInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/BitrixInstaller.php',
    'Composer\\Installers\\BonefishInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/BonefishInstaller.php',
    'Composer\\Installers\\CakePHPInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CakePHPInstaller.php',
    'Composer\\Installers\\ChefInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ChefInstaller.php',
    'Composer\\Installers\\CiviCrmInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CiviCrmInstaller.php',
    'Composer\\Installers\\ClanCatsFrameworkInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ClanCatsFrameworkInstaller.php',
    'Composer\\Installers\\CockpitInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CockpitInstaller.php',
    'Composer\\Installers\\CodeIgniterInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CodeIgniterInstaller.php',
    'Composer\\Installers\\Concrete5Installer' => $vendorDir . '/composer/installers/src/Composer/Installers/Concrete5Installer.php',
    'Composer\\Installers\\CraftInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CraftInstaller.php',
    'Composer\\Installers\\CroogoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CroogoInstaller.php',
    'Composer\\Installers\\DecibelInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DecibelInstaller.php',
    'Composer\\Installers\\DframeInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DframeInstaller.php',
    'Composer\\Installers\\DokuWikiInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DokuWikiInstaller.php',
    'Composer\\Installers\\DolibarrInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DolibarrInstaller.php',
    'Composer\\Installers\\DrupalInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DrupalInstaller.php',
    'Composer\\Installers\\ElggInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ElggInstaller.php',
    'Composer\\Installers\\EliasisInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/EliasisInstaller.php',
    'Composer\\Installers\\ExpressionEngineInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ExpressionEngineInstaller.php',
    'Composer\\Installers\\EzPlatformInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/EzPlatformInstaller.php',
    'Composer\\Installers\\FuelInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/FuelInstaller.php',
    'Composer\\Installers\\FuelphpInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/FuelphpInstaller.php',
    'Composer\\Installers\\GravInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/GravInstaller.php',
    'Composer\\Installers\\HuradInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/HuradInstaller.php',
    'Composer\\Installers\\ImageCMSInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ImageCMSInstaller.php',
    'Composer\\Installers\\Installer' => $vendorDir . '/composer/installers/src/Composer/Installers/Installer.php',
    'Composer\\Installers\\ItopInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ItopInstaller.php',
    'Composer\\Installers\\JoomlaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/JoomlaInstaller.php',
    'Composer\\Installers\\KanboardInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/KanboardInstaller.php',
    'Composer\\Installers\\KirbyInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/KirbyInstaller.php',
    'Composer\\Installers\\KnownInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/KnownInstaller.php',
    'Composer\\Installers\\KodiCMSInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/KodiCMSInstaller.php',
    'Composer\\Installers\\KohanaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/KohanaInstaller.php',
    'Composer\\Installers\\LanManagementSystemInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/LanManagementSystemInstaller.php',
    'Composer\\Installers\\LaravelInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/LaravelInstaller.php',
    'Composer\\Installers\\LavaLiteInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/LavaLiteInstaller.php',
    'Composer\\Installers\\LithiumInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/LithiumInstaller.php',
    'Composer\\Installers\\MODULEWorkInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MODULEWorkInstaller.php',
    'Composer\\Installers\\MODXEvoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MODXEvoInstaller.php',
    'Composer\\Installers\\MagentoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MagentoInstaller.php',
    'Composer\\Installers\\MajimaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MajimaInstaller.php',
    'Composer\\Installers\\MakoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MakoInstaller.php',
    'Composer\\Installers\\MantisBTInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MantisBTInstaller.php',
    'Composer\\Installers\\MauticInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MauticInstaller.php',
    'Composer\\Installers\\MayaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MayaInstaller.php',
    'Composer\\Installers\\MediaWikiInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MediaWikiInstaller.php',
    'Composer\\Installers\\MiaoxingInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MiaoxingInstaller.php',
    'Composer\\Installers\\MicroweberInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MicroweberInstaller.php',
    'Composer\\Installers\\ModxInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ModxInstaller.php',
    'Composer\\Installers\\MoodleInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MoodleInstaller.php',
    'Composer\\Installers\\OctoberInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/OctoberInstaller.php',
    'Composer\\Installers\\OntoWikiInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/OntoWikiInstaller.php',
    'Composer\\Installers\\OsclassInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/OsclassInstaller.php',
    'Composer\\Installers\\OxidInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/OxidInstaller.php',
    'Composer\\Installers\\PPIInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PPIInstaller.php',
    'Composer\\Installers\\PantheonInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PantheonInstaller.php',
    'Composer\\Installers\\PhiftyInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PhiftyInstaller.php',
    'Composer\\Installers\\PhpBBInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PhpBBInstaller.php',
    'Composer\\Installers\\PimcoreInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PimcoreInstaller.php',
    'Composer\\Installers\\PiwikInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PiwikInstaller.php',
    'Composer\\Installers\\PlentymarketsInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PlentymarketsInstaller.php',
    'Composer\\Installers\\Plugin' => $vendorDir . '/composer/installers/src/Composer/Installers/Plugin.php',
    'Composer\\Installers\\PortoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PortoInstaller.php',
    'Composer\\Installers\\PrestashopInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PrestashopInstaller.php',
    'Composer\\Installers\\ProcessWireInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ProcessWireInstaller.php',
    'Composer\\Installers\\PuppetInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PuppetInstaller.php',
    'Composer\\Installers\\PxcmsInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PxcmsInstaller.php',
    'Composer\\Installers\\RadPHPInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/RadPHPInstaller.php',
    'Composer\\Installers\\ReIndexInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ReIndexInstaller.php',
    'Composer\\Installers\\Redaxo5Installer' => $vendorDir . '/composer/installers/src/Composer/Installers/Redaxo5Installer.php',
    'Composer\\Installers\\RedaxoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/RedaxoInstaller.php',
    'Composer\\Installers\\RoundcubeInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/RoundcubeInstaller.php',
    'Composer\\Installers\\SMFInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/SMFInstaller.php',
    'Composer\\Installers\\ShopwareInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ShopwareInstaller.php',
    'Composer\\Installers\\SilverStripeInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/SilverStripeInstaller.php',
    'Composer\\Installers\\SiteDirectInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/SiteDirectInstaller.php',
    'Composer\\Installers\\StarbugInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/StarbugInstaller.php',
    'Composer\\Installers\\SyDESInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/SyDESInstaller.php',
    'Composer\\Installers\\SyliusInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/SyliusInstaller.php',
    'Composer\\Installers\\Symfony1Installer' => $vendorDir . '/composer/installers/src/Composer/Installers/Symfony1Installer.php',
    'Composer\\Installers\\TYPO3CmsInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TYPO3CmsInstaller.php',
    'Composer\\Installers\\TYPO3FlowInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TYPO3FlowInstaller.php',
    'Composer\\Installers\\TaoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TaoInstaller.php',
    'Composer\\Installers\\TastyIgniterInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TastyIgniterInstaller.php',
    'Composer\\Installers\\TheliaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TheliaInstaller.php',
    'Composer\\Installers\\TuskInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TuskInstaller.php',
    'Composer\\Installers\\UserFrostingInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/UserFrostingInstaller.php',
    'Composer\\Installers\\VanillaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/VanillaInstaller.php',
    'Composer\\Installers\\VgmcpInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/VgmcpInstaller.php',
    'Composer\\Installers\\WHMCSInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/WHMCSInstaller.php',
    'Composer\\Installers\\WinterInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/WinterInstaller.php',
    'Composer\\Installers\\WolfCMSInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/WolfCMSInstaller.php',
    'Composer\\Installers\\WordPressInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/WordPressInstaller.php',
    'Composer\\Installers\\YawikInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/YawikInstaller.php',
    'Composer\\Installers\\ZendInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ZendInstaller.php',
    'Composer\\Installers\\ZikulaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ZikulaInstaller.php',
    'MaxMind\\Db\\Reader' => $vendorDir . '/maxmind-db/reader/src/MaxMind/Db/Reader.php',
    'MaxMind\\Db\\Reader\\Decoder' => $vendorDir . '/maxmind-db/reader/src/MaxMind/Db/Reader/Decoder.php',
    'MaxMind\\Db\\Reader\\InvalidDatabaseException' => $vendorDir . '/maxmind-db/reader/src/MaxMind/Db/Reader/InvalidDatabaseException.php',
    'MaxMind\\Db\\Reader\\Metadata' => $vendorDir . '/maxmind-db/reader/src/MaxMind/Db/Reader/Metadata.php',
    'MaxMind\\Db\\Reader\\Util' => $vendorDir . '/maxmind-db/reader/src/MaxMind/Db/Reader/Util.php',
    'Pelago\\Emogrifier' => $vendorDir . '/pelago/emogrifier/src/Emogrifier.php',
    'Pelago\\Emogrifier\\CssInliner' => $vendorDir . '/pelago/emogrifier/src/Emogrifier/CssInliner.php',
    'Pelago\\Emogrifier\\HtmlProcessor\\AbstractHtmlProcessor' => $vendorDir . '/pelago/emogrifier/src/Emogrifier/HtmlProcessor/AbstractHtmlProcessor.php',
    'Pelago\\Emogrifier\\HtmlProcessor\\CssToAttributeConverter' => $vendorDir . '/pelago/emogrifier/src/Emogrifier/HtmlProcessor/CssToAttributeConverter.php',
    'Pelago\\Emogrifier\\HtmlProcessor\\HtmlNormalizer' => $vendorDir . '/pelago/emogrifier/src/Emogrifier/HtmlProcessor/HtmlNormalizer.php',
    'Pelago\\Emogrifier\\HtmlProcessor\\HtmlPruner' => $vendorDir . '/pelago/emogrifier/src/Emogrifier/HtmlProcessor/HtmlPruner.php',
    'Pelago\\Emogrifier\\Utilities\\ArrayIntersector' => $vendorDir . '/pelago/emogrifier/src/Emogrifier/Utilities/ArrayIntersector.php',
    'Pelago\\Emogrifier\\Utilities\\CssConcatenator' => $vendorDir . '/pelago/emogrifier/src/Emogrifier/Utilities/CssConcatenator.php',
    'Psr\\Container\\ContainerExceptionInterface' => $vendorDir . '/psr/container/src/ContainerExceptionInterface.php',
    'Psr\\Container\\ContainerInterface' => $vendorDir . '/psr/container/src/ContainerInterface.php',
    'Psr\\Container\\NotFoundExceptionInterface' => $vendorDir . '/psr/container/src/NotFoundExceptionInterface.php',
    'Symfony\\Component\\CssSelector\\CssSelectorConverter' => $vendorDir . '/symfony/css-selector/CssSelectorConverter.php',
    'Symfony\\Component\\CssSelector\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/css-selector/Exception/ExceptionInterface.php',
    'Symfony\\Component\\CssSelector\\Exception\\ExpressionErrorException' => $vendorDir . '/symfony/css-selector/Exception/ExpressionErrorException.php',
    'Symfony\\Component\\CssSelector\\Exception\\InternalErrorException' => $vendorDir . '/symfony/css-selector/Exception/InternalErrorException.php',
    'Symfony\\Component\\CssSelector\\Exception\\ParseException' => $vendorDir . '/symfony/css-selector/Exception/ParseException.php',
    'Symfony\\Component\\CssSelector\\Exception\\SyntaxErrorException' => $vendorDir . '/symfony/css-selector/Exception/SyntaxErrorException.php',
    'Symfony\\Component\\CssSelector\\Node\\AbstractNode' => $vendorDir . '/symfony/css-selector/Node/AbstractNode.php',
    'Symfony\\Component\\CssSelector\\Node\\AttributeNode' => $vendorDir . '/symfony/css-selector/Node/AttributeNode.php',
    'Symfony\\Component\\CssSelector\\Node\\ClassNode' => $vendorDir . '/symfony/css-selector/Node/ClassNode.php',
    'Symfony\\Component\\CssSelector\\Node\\CombinedSelectorNode' => $vendorDir . '/symfony/css-selector/Node/CombinedSelectorNode.php',
    'Symfony\\Component\\CssSelector\\Node\\ElementNode' => $vendorDir . '/symfony/css-selector/Node/ElementNode.php',
    'Symfony\\Component\\CssSelector\\Node\\FunctionNode' => $vendorDir . '/symfony/css-selector/Node/FunctionNode.php',
    'Symfony\\Component\\CssSelector\\Node\\HashNode' => $vendorDir . '/symfony/css-selector/Node/HashNode.php',
    'Symfony\\Component\\CssSelector\\Node\\NegationNode' => $vendorDir . '/symfony/css-selector/Node/NegationNode.php',
    'Symfony\\Component\\CssSelector\\Node\\NodeInterface' => $vendorDir . '/symfony/css-selector/Node/NodeInterface.php',
    'Symfony\\Component\\CssSelector\\Node\\PseudoNode' => $vendorDir . '/symfony/css-selector/Node/PseudoNode.php',
    'Symfony\\Component\\CssSelector\\Node\\SelectorNode' => $vendorDir . '/symfony/css-selector/Node/SelectorNode.php',
    'Symfony\\Component\\CssSelector\\Node\\Specificity' => $vendorDir . '/symfony/css-selector/Node/Specificity.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\CommentHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/CommentHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\HandlerInterface' => $vendorDir . '/symfony/css-selector/Parser/Handler/HandlerInterface.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\HashHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/HashHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\IdentifierHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/IdentifierHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\NumberHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/NumberHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\StringHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/StringHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\WhitespaceHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/WhitespaceHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Parser' => $vendorDir . '/symfony/css-selector/Parser/Parser.php',
    'Symfony\\Component\\CssSelector\\Parser\\ParserInterface' => $vendorDir . '/symfony/css-selector/Parser/ParserInterface.php',
    'Symfony\\Component\\CssSelector\\Parser\\Reader' => $vendorDir . '/symfony/css-selector/Parser/Reader.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\ClassParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/ClassParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\ElementParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/ElementParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\EmptyStringParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/EmptyStringParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\HashParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/HashParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Token' => $vendorDir . '/symfony/css-selector/Parser/Token.php',
    'Symfony\\Component\\CssSelector\\Parser\\TokenStream' => $vendorDir . '/symfony/css-selector/Parser/TokenStream.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\Tokenizer' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/Tokenizer.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\TokenizerEscaping' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/TokenizerEscaping.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\TokenizerPatterns' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/TokenizerPatterns.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\AbstractExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/AbstractExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\AttributeMatchingExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/AttributeMatchingExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\CombinationExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/CombinationExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\ExtensionInterface' => $vendorDir . '/symfony/css-selector/XPath/Extension/ExtensionInterface.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\FunctionExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/FunctionExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\HtmlExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/HtmlExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\NodeExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/NodeExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\PseudoClassExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/PseudoClassExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Translator' => $vendorDir . '/symfony/css-selector/XPath/Translator.php',
    'Symfony\\Component\\CssSelector\\XPath\\TranslatorInterface' => $vendorDir . '/symfony/css-selector/XPath/TranslatorInterface.php',
    'Symfony\\Component\\CssSelector\\XPath\\XPathExpr' => $vendorDir . '/symfony/css-selector/XPath/XPathExpr.php',
    'WC_REST_CRUD_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-crud-controller.php',
    'WC_REST_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-controller.php',
    'WC_REST_Coupons_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-coupons-controller.php',
    'WC_REST_Coupons_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-coupons-v1-controller.php',
    'WC_REST_Coupons_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-coupons-v2-controller.php',
    'WC_REST_Customer_Downloads_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-customer-downloads-controller.php',
    'WC_REST_Customer_Downloads_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-customer-downloads-v1-controller.php',
    'WC_REST_Customer_Downloads_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-customer-downloads-v2-controller.php',
    'WC_REST_Customers_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-customers-controller.php',
    'WC_REST_Customers_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-customers-v1-controller.php',
    'WC_REST_Customers_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-customers-v2-controller.php',
    'WC_REST_Data_Continents_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-data-continents-controller.php',
    'WC_REST_Data_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-data-controller.php',
    'WC_REST_Data_Countries_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-data-countries-controller.php',
    'WC_REST_Data_Currencies_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-data-currencies-controller.php',
    'WC_REST_Network_Orders_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-network-orders-controller.php',
    'WC_REST_Network_Orders_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-network-orders-v2-controller.php',
    'WC_REST_Order_Notes_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-order-notes-controller.php',
    'WC_REST_Order_Notes_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-order-notes-v1-controller.php',
    'WC_REST_Order_Notes_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-order-notes-v2-controller.php',
    'WC_REST_Order_Refunds_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-order-refunds-controller.php',
    'WC_REST_Order_Refunds_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-order-refunds-v1-controller.php',
    'WC_REST_Order_Refunds_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-order-refunds-v2-controller.php',
    'WC_REST_Orders_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-orders-controller.php',
    'WC_REST_Orders_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-orders-v1-controller.php',
    'WC_REST_Orders_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-orders-v2-controller.php',
    'WC_REST_Payment_Gateways_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-payment-gateways-controller.php',
    'WC_REST_Payment_Gateways_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-payment-gateways-v2-controller.php',
    'WC_REST_Posts_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-posts-controller.php',
    'WC_REST_Product_Attribute_Terms_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-product-attribute-terms-controller.php',
    'WC_REST_Product_Attribute_Terms_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-product-attribute-terms-v1-controller.php',
    'WC_REST_Product_Attribute_Terms_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-product-attribute-terms-v2-controller.php',
    'WC_REST_Product_Attributes_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-product-attributes-controller.php',
    'WC_REST_Product_Attributes_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-product-attributes-v1-controller.php',
    'WC_REST_Product_Attributes_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-product-attributes-v2-controller.php',
    'WC_REST_Product_Categories_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-product-categories-controller.php',
    'WC_REST_Product_Categories_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-product-categories-v1-controller.php',
    'WC_REST_Product_Categories_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-product-categories-v2-controller.php',
    'WC_REST_Product_Reviews_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-product-reviews-controller.php',
    'WC_REST_Product_Reviews_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-product-reviews-v1-controller.php',
    'WC_REST_Product_Reviews_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-product-reviews-v2-controller.php',
    'WC_REST_Product_Shipping_Classes_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-product-shipping-classes-controller.php',
    'WC_REST_Product_Shipping_Classes_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-product-shipping-classes-v1-controller.php',
    'WC_REST_Product_Shipping_Classes_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-product-shipping-classes-v2-controller.php',
    'WC_REST_Product_Tags_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-product-tags-controller.php',
    'WC_REST_Product_Tags_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-product-tags-v1-controller.php',
    'WC_REST_Product_Tags_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-product-tags-v2-controller.php',
    'WC_REST_Product_Variations_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-product-variations-controller.php',
    'WC_REST_Product_Variations_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-product-variations-v2-controller.php',
    'WC_REST_Products_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-products-controller.php',
    'WC_REST_Products_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-products-v1-controller.php',
    'WC_REST_Products_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-products-v2-controller.php',
    'WC_REST_Report_Coupons_Totals_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-report-coupons-totals-controller.php',
    'WC_REST_Report_Customers_Totals_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-report-customers-totals-controller.php',
    'WC_REST_Report_Orders_Totals_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-report-orders-totals-controller.php',
    'WC_REST_Report_Products_Totals_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-report-products-totals-controller.php',
    'WC_REST_Report_Reviews_Totals_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-report-reviews-totals-controller.php',
    'WC_REST_Report_Sales_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-report-sales-controller.php',
    'WC_REST_Report_Sales_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-report-sales-v1-controller.php',
    'WC_REST_Report_Sales_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-report-sales-v2-controller.php',
    'WC_REST_Report_Top_Sellers_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-report-top-sellers-controller.php',
    'WC_REST_Report_Top_Sellers_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-report-top-sellers-v1-controller.php',
    'WC_REST_Report_Top_Sellers_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-report-top-sellers-v2-controller.php',
    'WC_REST_Reports_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-reports-controller.php',
    'WC_REST_Reports_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-reports-v1-controller.php',
    'WC_REST_Reports_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-reports-v2-controller.php',
    'WC_REST_Setting_Options_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-setting-options-controller.php',
    'WC_REST_Setting_Options_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-setting-options-v2-controller.php',
    'WC_REST_Settings_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-settings-controller.php',
    'WC_REST_Settings_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-settings-v2-controller.php',
    'WC_REST_Shipping_Methods_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-shipping-methods-controller.php',
    'WC_REST_Shipping_Methods_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-shipping-methods-v2-controller.php',
    'WC_REST_Shipping_Zone_Locations_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-shipping-zone-locations-controller.php',
    'WC_REST_Shipping_Zone_Locations_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-shipping-zone-locations-v2-controller.php',
    'WC_REST_Shipping_Zone_Methods_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-shipping-zone-methods-controller.php',
    'WC_REST_Shipping_Zone_Methods_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-shipping-zone-methods-v2-controller.php',
    'WC_REST_Shipping_Zones_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-shipping-zones-controller.php',
    'WC_REST_Shipping_Zones_Controller_Base' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-shipping-zones-controller-base.php',
    'WC_REST_Shipping_Zones_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-shipping-zones-v2-controller.php',
    'WC_REST_System_Status_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-system-status-controller.php',
    'WC_REST_System_Status_Tools_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-system-status-tools-controller.php',
    'WC_REST_System_Status_Tools_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-system-status-tools-v2-controller.php',
    'WC_REST_System_Status_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-system-status-v2-controller.php',
    'WC_REST_Tax_Classes_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-tax-classes-controller.php',
    'WC_REST_Tax_Classes_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-tax-classes-v1-controller.php',
    'WC_REST_Tax_Classes_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-tax-classes-v2-controller.php',
    'WC_REST_Taxes_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-taxes-controller.php',
    'WC_REST_Taxes_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-taxes-v1-controller.php',
    'WC_REST_Taxes_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-taxes-v2-controller.php',
    'WC_REST_Telemetry_Controller' => $baseDir . '/includes/rest-api/Controllers/Telemetry/class-wc-rest-telemetry-controller.php',
    'WC_REST_Terms_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-terms-controller.php',
    'WC_REST_Webhook_Deliveries_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-webhook-deliveries-v1-controller.php',
    'WC_REST_Webhook_Deliveries_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-webhook-deliveries-v2-controller.php',
    'WC_REST_Webhooks_Controller' => $baseDir . '/includes/rest-api/Controllers/Version3/class-wc-rest-webhooks-controller.php',
    'WC_REST_Webhooks_V1_Controller' => $baseDir . '/includes/rest-api/Controllers/Version1/class-wc-rest-webhooks-v1-controller.php',
    'WC_REST_Webhooks_V2_Controller' => $baseDir . '/includes/rest-api/Controllers/Version2/class-wc-rest-webhooks-v2-controller.php',
);
